@@ -2,10 +2,10 @@
 import unittest
 
 from ansiblelint.rules import RulesCollection
-from ansiblelint.rules.LineTooLongRule import LineTooLongRule
+from ansiblelint.rules.YamllintRule import YamllintRule
 from ansiblelint.testing import RunFromText
 
-LONG_LINE = '''
+LONG_LINE = '''\
 - name: task example
   debug:
     msg: 'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua tempor incididunt ut labore et dolore'
@@ -14,11 +14,11 @@ LONG_LINE = '''
 
 class TestLineTooLongRule(unittest.TestCase):
     collection = RulesCollection()
-    collection.register(LineTooLongRule())
+    collection.register(YamllintRule())
 
-    def setUp(self):
+    def setUp(self) -> None:
         self.runner = RunFromText(self.collection)
 
-    def test_long_line(self):
+    def test_long_line(self) -> None:
         results = self.runner.run_role_tasks_main(LONG_LINE)
         self.assertEqual(1, len(results))
