@@ -1,4 +1,7 @@
-def test_serverity_valid(default_rules_collection):
+from ansiblelint.rules import RulesCollection
+
+
+def test_serverity_valid(default_rules_collection: RulesCollection) -> None:
     valid_severity_values = [
         'VERY_HIGH',
         'HIGH',
