@@ -1,89 +1,84 @@
 import pytest
 
-ROLE_TASKS = '''
+from ansiblelint.testing import RunFromText
+
+ROLE_TASKS = '''\
 ---
-- name: test 303
-  command: git log
-  changed_when: False
-- name: test 303 (skipped)
-  command: git log # noqa 303
-  changed_when: False
+- debug:
+    msg: this should fail linting due lack of name
+- debug:  # noqa unnamed-task
+    msg: this should pass due to noqa comment
 '''
 
-ROLE_TASKS_WITH_BLOCK = '''
+ROLE_TASKS_WITH_BLOCK = '''\
 ---
-- name: bad git 1  # noqa 401
+- name: bad git 1  # noqa git-latest
   action: git a=b c=d
 - name: bad git 2
   action: git a=b c=d
 - name: Block with rescue and always section
   block:
-    - name: bad git 3  # noqa 401
+    - name: bad git 3  # noqa git-latest
       action: git a=b c=d
     - name: bad git 4
       action: git a=b c=d
   rescue:
-    - name: bad git 5  # noqa 401
+    - name: bad git 5  # noqa git-latest
       action: git a=b c=d
     - name: bad git 6
       action: git a=b c=d
   always:
-    - name: bad git 7  # noqa 401
+    - name: bad git 7  # noqa git-latest
       action: git a=b c=d
     - name: bad git 8
       action: git a=b c=d
 '''
 
-PLAYBOOK = '''
+PLAYBOOK = '''\
 - hosts: all
   tasks:
-    - name: test 402
+    - name: test hg-latest
       action: hg
-    - name: test 402 (skipped)  # noqa 402
+    - name: test hg-latest (skipped)  # noqa hg-latest
       action: hg
 
-    - name: test 401 and 501
+    - name: test git-latest and partial-become
       become_user: alice
       action: git
-    - name: test 401 and 501 (skipped)  # noqa 401 501
+    - name: test git-latest and partial-become (skipped)  # noqa git-latest partial-become
       become_user: alice
       action: git
 
-    - name: test 204 and 206
+    - name: test YAML and var-spacing
       get_url:
         url: http://example.com/really_long_path/really_long_path/really_long_path/really_long_path/really_long_path/really_long_path/really_long_path/really_long_path/file.conf
         dest: "{{dest_proj_path}}/foo.conf"
-    - name: test 204 and 206 (skipped)
+    - name: test YAML and var-spacing (skipped)
       get_url:
-        url: http://example.com/really_long_path/really_long_path/really_long_path/really_long_path/really_long_path/really_long_path/really_long_path/really_long_path/file.conf  # noqa 204
-        dest: "{{dest_proj_path}}/foo.conf"  # noqa 206
+        url: http://example.com/really_long_path/really_long_path/really_long_path/really_long_path/really_long_path/really_long_path/really_long_path/really_long_path/file.conf  # noqa yaml
+        dest: "{{dest_proj_path}}/foo.conf"  # noqa var-spacing
 
-    - name: test 302
+    - name: test deprecated-command-syntax
       command: creates=B chmod 644 A
-    - name: test 302
+    - name: test deprecated-command-syntax
       command: warn=yes creates=B chmod 644 A
-    - name: test 302 (skipped via no warn)
+    - name: test deprecated-command-syntax (skipped via no warn)
       command: warn=no creates=B chmod 644 A
-    - name: test 302 (skipped via skip_ansible_lint)
+    - name: test deprecated-command-syntax (skipped via skip_ansible_lint)
       command: creates=B chmod 644 A
       tags:
         - skip_ansible_lint
-
-    - name: test invalid action (skipped)
-      foo: bar
-      tags:
-        - skip_ansible_lint
 '''
 
-ROLE_META = '''
-galaxy_info:  # noqa 701
-  author: your name  # noqa 703
+ROLE_META = '''\
+galaxy_info:  # noqa meta-no-info
+  author: your name  # noqa meta-incorrect
   description: missing min_ansible_version and platforms. author default not changed
   license: MIT
 '''
 
-ROLE_TASKS_WITH_BLOCK_BECOME = '''
-- hosts:
+ROLE_TASKS_WITH_BLOCK_BECOME = '''\
+- hosts: localhost
   tasks:
     - name: foo
       become: true
@@ -94,12 +89,14 @@ ROLE_TASKS_WITH_BLOCK_BECOME = '''
 '''
 
 
-def test_role_tasks(default_text_runner):
+def test_role_tasks(default_text_runner: RunFromText) -> None:
     results = default_text_runner.run_role_tasks_main(ROLE_TASKS)
-    assert len(results) == 1
+    assert len(results) == 1, results
+    assert results[0].linenumber == 2
+    assert results[0].rule.id == "unnamed-task"
 
 
-def test_role_tasks_with_block(default_text_runner):
+def test_role_tasks_with_block(default_text_runner: RunFromText) -> None:
     results = default_text_runner.run_role_tasks_main(ROLE_TASKS_WITH_BLOCK)
     assert len(results) == 4
 
@@ -112,11 +109,13 @@ def test_role_tasks_with_block(default_text_runner):
     ),
     ids=('generic', 'with block become inheritance'),
 )
-def test_playbook(default_text_runner, playbook_src, results_num):
+def test_playbook(
+    default_text_runner: RunFromText, playbook_src: str, results_num: int
+) -> None:
     results = default_text_runner.run_playbook(playbook_src)
     assert len(results) == results_num
 
 
-def test_role_meta(default_text_runner):
+def test_role_meta(default_text_runner: RunFromText) -> None:
     results = default_text_runner.run_role_meta_main(ROLE_META)
     assert len(results) == 0
